#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const adbkit_1 = __importDefault(require("@devicefarmer/adbkit"));
const bluebird_1 = __importStar(require("bluebird"));
const fs_1 = __importDefault(require("fs"));
const glob_1 = __importDefault(require("glob"));
const client = adbkit_1.default.createClient();
/* istanbul ignore next */
const run = async () => {
    try {
        const devices = await client.listDevices();
        if (devices.length === 0) {
            console.error(`Cannot communicate with Evam device. Make sure your device is connected.`);
            return;
        }
        if (!fs_1.default.existsSync('build/.')) {
            console.error("No build directory found, make sure to run 'npm run build'.");
            return;
        }
        await bluebird_1.default.map(devices, async (device) => {
            const dev = await client.getDevice(device.id);
            console.log(`Installing to ${dev.serial}...`);
            // Create development directory on device
            const comCreateDirWww = await dev.shell("mkdir -p /data/local/tmp/life.evam.hydras/dist/www/");
            await new bluebird_1.default((resolve, reject) => {
                comCreateDirWww.on('end', () => {
                    console.log("Created directory");
                    resolve();
                });
                comCreateDirWww.on('error', (e) => {
                    console.error("Failed to create directory");
                    reject(e);
                });
            });
            const comCreateDirMeta = await dev.shell("mkdir -p /data/local/tmp/life.evam.hydras/dist/meta/");
            await new bluebird_1.default((resolve, reject) => {
                comCreateDirMeta.on('end', () => {
                    console.log("Created directory");
                    resolve();
                });
                comCreateDirMeta.on('error', (e) => {
                    console.error("Failed to create directory");
                    reject(e);
                });
            });
            // Push build directory
            (0, glob_1.default)("build/**", (er, files) => {
                files.forEach(async (file) => {
                    if (fs_1.default.lstatSync(file).isDirectory()) {
                        const fileOnDevice = file.replace("build", "");
                        let targetDir = "www";
                        if (fileOnDevice.includes("evam.json")) {
                            targetDir = "meta";
                        }
                        console.log(`Pushing ${fileOnDevice}`);
                        const comCreateDir = await dev.shell(`mkdir -p /data/local/tmp/life.evam.hydras/dist/${targetDir}/${fileOnDevice}`);
                        await new bluebird_1.default((resolve, reject) => {
                            comCreateDir.on('error', (e) => {
                                console.error(`Failed to create ${file}`);
                                reject(e);
                            });
                        });
                    }
                    else {
                        const fileOnDevice = file.replace("build", "");
                        console.log(`Pushing ${fileOnDevice}`);
                        let targetDir = "www";
                        if (fileOnDevice.includes("evam.json")) {
                            targetDir = "meta";
                        }
                        const comPush = await dev.push(file, `/data/local/tmp/life.evam.hydras/dist/${targetDir}/${fileOnDevice}`);
                        await new bluebird_1.default((resolve, reject) => {
                            comPush.on('error', (e) => {
                                console.error(`Failed pushing ${file}`);
                                reject(e);
                            });
                        });
                    }
                });
            });
        });
    }
    catch (e) {
        console.error(e);
        (0, bluebird_1.reject)(e);
    }
};
run()
    .then(() => { console.log(""); })
    .catch((e) => { console.error(`Failed: ${e}`); });
//# sourceMappingURL=wrapper.js.map